@@ -132,13 +132,14 @@ def check_language(command_line_params, yaml_config):
     if 'language' in yaml_config and yaml_config['language'] is not None:
         languages = yaml_config['language'].split(',')
         for language in languages:
+            language =  language.strip()
             if language in LANGUAGES:
                 if language == 'python3':
                     language = 'python'
 
                 yaml_language.append(language)
             else:
-                print("Scanner for %s hasn't been supported." % language)
+                print("Scanner for %s isn't supported." % language)
 
     if len(yaml_language) > 0:
         yaml_config['language'] = Utils.remove_duplicated_items_list(yaml_language)
@@ -148,7 +149,7 @@ def check_language(command_line_params, yaml_config):
     return 'language' in yaml_config or 'language' in command_line_params or (scanners != '' and scanners.find('sast') < 0)
 
 def version():
-    return '0.1.83'
+    return '0.1.85'
 
 def main():
     command_line_params, command_args = parse_command_line_params()
